Dyff 0.7.0 release
==================

- Implement ``delete`` endpoints for all resources. Deleted resources remain in the database but have status ``"Deleted"`` and can't be used as dependencies.

- Change the inference session ``terminate`` endpoint to use ``PUT`` for symmetry with the ``delete`` endpoints.
